@@ -53,7 +53,6 @@ macro_rules! finish_list_builder {
             field: Arc::new($self.field.clone()),
             chunks: vec![arr],
             phantom: PhantomData,
-            categorical_map: None,
             ..Default::default()
         };
         ca.compute_len();
@@ -85,17 +84,19 @@ where
         }
     }
 
-    pub fn append_slice(&mut self, opt_v: Option<&[T::Native]>) {
-        match opt_v {
-            Some(items) => {
-                let values = self.builder.mut_values();
-                values.extend_from_slice(items);
-                self.builder.try_push_valid().unwrap();
+    pub fn append_slice(&mut self, items: &[T::Native]) {
+        let values = self.builder.mut_values();
+        values.extend_from_slice(items);
+        self.builder.try_push_valid().unwrap();
 
-                if items.is_empty() {
-                    self.fast_explode = false;
-                }
-            }
+        if items.is_empty() {
+            self.fast_explode = false;
+        }
+    }
+
+    pub fn append_opt_slice(&mut self, opt_v: Option<&[T::Native]>) {
+        match opt_v {
+            Some(items) => self.append_slice(items),
             None => {
                 self.builder.push_null();
             }
@@ -642,9 +643,7 @@ impl ListBuilderTrait for AnonymousOwnedListBuilder {
                 let dtype = slf.inner_dtype.unwrap_or(NULL_DTYPE).to_arrow();
                 let array = new_null_array(dtype.clone(), real_length);
                 let dtype = ListArray::<i64>::default_datatype(dtype);
-                let array = unsafe {
-                    ListArray::new_unchecked(dtype, slf.builder.take_offsets().into(), array, None)
-                };
+                let array = ListArray::new(dtype, slf.builder.take_offsets().into(), array, None);
                 ListChunked::from_chunks(&slf.name, vec![Box::new(array)])
             } else {
                 ListChunked::full_null_with_dtype(
