@@ -16,13 +16,19 @@ impl LogicalType for DatetimeChunked {
         self.2.as_ref().unwrap()
     }
 
-    fn get_any_value(&self, i: usize) -> AnyValue<'_> {
+    fn get_any_value(&self, i: usize) -> PolarsResult<AnyValue<'_>> {
         self.0
             .get_any_value(i)
+            .map(|av| av.into_datetime(self.time_unit(), self.time_zone()))
+    }
+
+    unsafe fn get_any_value_unchecked(&self, i: usize) -> AnyValue<'_> {
+        self.0
+            .get_any_value_unchecked(i)
             .into_datetime(self.time_unit(), self.time_zone())
     }
 
-    fn cast(&self, dtype: &DataType) -> Result<Series> {
+    fn cast(&self, dtype: &DataType) -> PolarsResult<Series> {
         use DataType::*;
         match (self.dtype(), dtype) {
             (Datetime(TimeUnit::Milliseconds, _), Datetime(TimeUnit::Nanoseconds, tz)) => {
