@@ -21,8 +21,11 @@ impl LogicalType for TimeChunked {
     }
 
     #[cfg(feature = "dtype-time")]
-    fn get_any_value(&self, i: usize) -> AnyValue<'_> {
-        self.0.get_any_value(i).into_time()
+    fn get_any_value(&self, i: usize) -> PolarsResult<AnyValue<'_>> {
+        self.0.get_any_value(i).map(|av| av.into_time())
+    }
+    unsafe fn get_any_value_unchecked(&self, i: usize) -> AnyValue<'_> {
+        self.0.get_any_value_unchecked(i).into_time()
     }
 
     fn cast(&self, dtype: &DataType) -> PolarsResult<Series> {
