@@ -20,7 +20,7 @@ unsafe fn create_drop<T: Sized>(mut ptr: *const u8, n_t_vals: usize) -> Box<dyn
         let t_size = std::mem::size_of::<T>() as isize;
         for _ in 0..n_t_vals {
             let _ = std::ptr::read_unaligned(ptr as *const T);
-            ptr = ptr.offset(t_size as isize)
+            ptr = ptr.offset(t_size)
         }
     })
 }
@@ -56,10 +56,7 @@ pub(crate) fn create_extension<
 ) -> PolarsExtension {
     let env = "POLARS_ALLOW_EXTENSION";
     std::env::var(env).unwrap_or_else(|_| {
-        panic!(
-            "env var: {} must be set to allow extension types to be created",
-            env
-        )
+        panic!("env var: {env} must be set to allow extension types to be created",)
     });
     let t_size = std::mem::size_of::<T>();
     let t_alignment = std::mem::align_of::<T>();
@@ -130,7 +127,7 @@ pub(crate) fn create_extension<
         None
     };
 
-    let array = FixedSizeBinaryArray::from_data(extension_type, buf, validity);
+    let array = FixedSizeBinaryArray::new(extension_type, buf, validity);
 
     // Safety:
     // we just heap allocated the ExtensionSentinel, so its alive.
