@@ -143,7 +143,7 @@ pub fn concat_str(s: &[Series], delimiter: &str) -> PolarsResult<Utf8Chunked> {
             "expected multiple series in concat_str function".into(),
         ));
     }
-    if s[0].is_empty() {
+    if s.iter().any(|s| s.is_empty()) {
         return Ok(Utf8Chunked::full_null(s[0].name(), 0));
     }
 
@@ -165,7 +165,7 @@ pub fn concat_str(s: &[Series], delimiter: &str) -> PolarsResult<Utf8Chunked> {
 
     if !s.iter().all(|s| s.len() == 1 || s.len() == len) {
         return Err(PolarsError::ComputeError(
-            "all series in concat_str function should have equal length or unit length".into(),
+            "All series in concat_str function should have equal length or unit length".into(),
         ));
     }
     let mut iters = cas
@@ -256,6 +256,7 @@ pub fn hor_concat_df(dfs: &[DataFrame]) -> PolarsResult<DataFrame> {
 #[cfg_attr(docsrs, doc(cfg(feature = "diagonal_concat")))]
 /// Concat diagonally thereby combining different schemas.
 pub fn diag_concat_df(dfs: &[DataFrame]) -> PolarsResult<DataFrame> {
+    // TODO! replace with lazy only?
     let upper_bound_width = dfs.iter().map(|df| df.width()).sum();
     let mut column_names = AHashSet::with_capacity(upper_bound_width);
     let mut schema = Vec::with_capacity(upper_bound_width);
