@@ -156,11 +156,7 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
                 Ok(lhs.subtract(&rhs)?.into_duration(*tu).into_series())
             }
             (dtl, dtr) => Err(PolarsError::ComputeError(
-                format!(
-                    "cannot do subtraction on these date types: {:?}, {:?}",
-                    dtl, dtr
-                )
-                .into(),
+                format!("cannot do subtraction on these date types: {dtl:?}, {dtr:?}",).into(),
             )),
         }
     }
@@ -182,11 +178,7 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
                     .into_series())
             }
             (dtl, dtr) => Err(PolarsError::ComputeError(
-                format!(
-                    "cannot do addition on these date types: {:?}, {:?}",
-                    dtl, dtr
-                )
-                .into(),
+                format!("cannot do addition on these date types: {dtl:?}, {dtr:?}",).into(),
             )),
         }
     }
@@ -368,16 +360,14 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
         self.0.cast(data_type)
     }
 
-    fn get(&self, index: usize) -> AnyValue {
+    fn get(&self, index: usize) -> PolarsResult<AnyValue> {
         self.0.get_any_value(index)
     }
 
     #[inline]
     #[cfg(feature = "private")]
     unsafe fn get_unchecked(&self, index: usize) -> AnyValue {
-        self.0
-            .get_any_value_unchecked(index)
-            .into_duration(self.0.time_unit())
+        self.0.get_any_value_unchecked(index)
     }
 
     fn sort_with(&self, options: SortOptions) -> Series {
