@@ -380,7 +380,7 @@ macro_rules! impl_dyn_series {
                 self.0.cast(data_type)
             }
 
-            fn get(&self, index: usize) -> AnyValue {
+            fn get(&self, index: usize) -> PolarsResult<AnyValue> {
                 self.0.get_any_value(index)
             }
 
