@@ -392,7 +392,7 @@ pub trait SeriesTrait:
 
     /// Get a single value by index. Don't use this operation for loops as a runtime cast is
     /// needed for every iteration.
-    fn get(&self, _index: usize) -> AnyValue {
+    fn get(&self, _index: usize) -> PolarsResult<AnyValue> {
         invalid_operation_panic!(self)
     }
 
