@@ -29,14 +29,23 @@ fn column_idx_to_series(
     bytes: &[u8],
     chunk_size: usize,
 ) -> PolarsResult<Series> {
-    let field = &schema.fields[column_i];
+    let mut field = schema.fields[column_i].clone();
+
+    match field.data_type {
+        ArrowDataType::Utf8 => {
+            field.data_type = ArrowDataType::LargeUtf8;
+        }
+        ArrowDataType::List(fld) => field.data_type = ArrowDataType::LargeList(fld),
+        _ => {}
+    }
+
     let columns = mmap_columns(bytes, md.columns(), &field.name);
     let iter = mmap::to_deserializer(columns, field.clone(), remaining_rows, Some(chunk_size))?;
 
     if remaining_rows < md.num_rows() {
-        array_iter_to_series(iter, field, Some(remaining_rows))
+        array_iter_to_series(iter, &field, Some(remaining_rows))
     } else {
-        array_iter_to_series(iter, field, None)
+        array_iter_to_series(iter, &field, None)
     }
 }
 
@@ -307,6 +316,7 @@ pub struct BatchedParquetReader {
     n_row_groups: usize,
     chunks_fifo: VecDeque<DataFrame>,
     parallel: ParallelStrategy,
+    chunk_size: usize,
 }
 
 impl BatchedParquetReader {
@@ -315,6 +325,7 @@ impl BatchedParquetReader {
         limit: usize,
         projection: Option<Vec<usize>>,
         row_count: Option<RowCount>,
+        chunk_size: usize,
     ) -> PolarsResult<Self> {
         let metadata = read::read_metadata(&mut reader)?;
         let schema = read::schema::infer_schema(&metadata)?;
@@ -351,6 +362,7 @@ impl BatchedParquetReader {
             n_row_groups,
             chunks_fifo: VecDeque::with_capacity(POOL.current_num_threads()),
             parallel,
+            chunk_size,
         })
     }
 
@@ -399,7 +411,7 @@ impl BatchedParquetReader {
 
             for mut df in dfs {
                 // make sure that the chunks are not too large
-                let n = df.shape().0 / 50_000;
+                let n = df.shape().0 / self.chunk_size;
                 if n > 1 {
                     for df in split_df(&mut df, n)? {
                         self.chunks_fifo.push_back(df)
