@@ -9,6 +9,7 @@ pub enum ListFunction {
     #[cfg(feature = "is_in")]
     Contains,
     Slice,
+    Get,
 }
 
 impl Display for ListFunction {
@@ -17,10 +18,12 @@ impl Display for ListFunction {
 
         let name = match self {
             Concat => "concat",
+            #[cfg(feature = "is_in")]
             Contains => "contains",
             Slice => "slice",
+            Get => "get",
         };
-        write!(f, "{}", name)
+        write!(f, "{name}")
     }
 }
 
@@ -43,15 +46,15 @@ pub(super) fn slice(args: &mut [Series]) -> PolarsResult<Series> {
 
     let mut out: ListChunked = match (offset_s.len(), length_s.len()) {
         (1, 1) => {
-            let offset = offset_s.get(0).try_extract::<i64>()?;
-            let slice_len = length_s.get(0).try_extract::<usize>()?;
+            let offset = offset_s.get(0).unwrap().try_extract::<i64>()?;
+            let slice_len = length_s.get(0).unwrap().try_extract::<usize>()?;
             return Ok(list_ca.lst_slice(offset, slice_len).into_series());
         }
         (1, length_slice_len) => {
             if length_slice_len != list_ca.len() {
                 return Err(PolarsError::ComputeError("the length of the slice 'length' argument does not match that of the list column".into()));
             }
-            let offset = offset_s.get(0).try_extract::<i64>()?;
+            let offset = offset_s.get(0).unwrap().try_extract::<i64>()?;
             // cast to i64 as it is more likely that it is that dtype
             // instead of usize/u64 (we never need that max length)
             let length_ca = length_s.cast(&DataType::Int64)?;
@@ -70,16 +73,14 @@ pub(super) fn slice(args: &mut [Series]) -> PolarsResult<Series> {
             if offset_len != list_ca.len() {
                 return Err(PolarsError::ComputeError("the length of the slice 'offset' argument does not match that of the list column".into()));
             }
-            let length_slice = length_s.get(0).try_extract::<usize>()?;
+            let length_slice = length_s.get(0).unwrap().try_extract::<usize>()?;
             let offset_ca = offset_s.cast(&DataType::Int64)?;
             let offset_ca = offset_ca.i64().unwrap();
             list_ca
                 .amortized_iter()
                 .zip(offset_ca)
                 .map(|(opt_s, opt_offset)| match (opt_s, opt_offset) {
-                    (Some(s), Some(offset)) => {
-                        Some(s.as_ref().slice(offset, length_slice as usize))
-                    }
+                    (Some(s), Some(offset)) => Some(s.as_ref().slice(offset, length_slice)),
                     _ => None,
                 })
                 .collect_trusted()
@@ -130,3 +131,49 @@ pub(super) fn concat(s: &mut [Series]) -> PolarsResult<Series> {
     };
     first_ca.lst_concat(other).map(|ca| ca.into_series())
 }
+
+pub(super) fn get(s: &mut [Series]) -> PolarsResult<Series> {
+    let ca = s[0].list()?;
+    let index = s[1].cast(&DataType::Int64)?;
+    let index = index.i64().unwrap();
+
+    match index.len() {
+        1 => {
+            let index = index.get(0);
+            if let Some(index) = index {
+                ca.lst_get(index)
+            } else {
+                Err(PolarsError::ComputeError("Expression 'arr.get' expected a valid index, got 'null' instead.".into()))
+            }
+        }
+        len if len == ca.len() => {
+            let ca = ca.rechunk();
+            let arr = ca.downcast_iter().next().unwrap();
+            let offsets = arr.offsets().as_slice();
+
+            let take_by = index.into_iter().enumerate().map(|(i, opt_idx)| {
+                opt_idx.and_then(|idx| {
+                    let (start, end) =  unsafe {
+                        (*offsets.get_unchecked(i), *offsets.get_unchecked(i + 1))
+                    };
+                    let offset = if idx >= 0 {
+                        start + idx
+                    } else {
+                        end + idx
+                    };
+                    if offset > end || offset < start || start == end {
+                        None
+                    } else {
+                        Some(offset as IdxSize)
+                    }
+                })
+            }).collect::<IdxCa>();
+            let s = Series::try_from((ca.name(), arr.values().clone())).unwrap();
+            unsafe { s.take_unchecked(&take_by) }
+        }
+        len => {
+            Err(PolarsError::ComputeError(format!("Expression 'arr.get' got an index array of length: {} where there were {} elements in the list.", len, ca.len()).into()))
+        }
+
+    }
+}
