@@ -145,6 +145,10 @@ pub enum ALogicalPlan {
         contexts: Vec<Node>,
         schema: SchemaRef,
     },
+    FileSink {
+        input: Node,
+        payload: FileSinkOptions,
+    },
 }
 
 impl Default for ALogicalPlan {
@@ -221,7 +225,9 @@ impl ALogicalPlan {
             Aggregate { schema, .. } => schema,
             Join { schema, .. } => schema,
             HStack { schema, .. } => schema,
-            Distinct { input, .. } => return arena.get(*input).schema(arena),
+            Distinct { input, .. } | FileSink { input, .. } => {
+                return arena.get(*input).schema(arena)
+            }
             Slice { input, .. } => return arena.get(*input).schema(arena),
             Melt { schema, .. } => schema,
             MapFunction { input, function } => {
@@ -454,6 +460,10 @@ impl ALogicalPlan {
                 contexts: inputs,
                 schema: schema.clone(),
             },
+            FileSink { payload, .. } => FileSink {
+                input: inputs.pop().unwrap(),
+                payload: payload.clone(),
+            },
         }
     }
 
@@ -513,7 +523,7 @@ impl ALogicalPlan {
                     container.push(*node)
                 }
             }
-            ExtContext { .. } => {}
+            ExtContext { .. } | FileSink { .. } => {}
         }
     }
 
@@ -560,6 +570,7 @@ impl ALogicalPlan {
             HStack { input, .. } => *input,
             Distinct { input, .. } => *input,
             MapFunction { input, .. } => *input,
+            FileSink { input, .. } => *input,
             ExtContext {
                 input, contexts, ..
             } => {
