@@ -20,7 +20,7 @@ pub enum PyPolarsErr {
 
 impl std::convert::From<std::io::Error> for PyPolarsErr {
     fn from(value: Error) -> Self {
-        PyPolarsErr::Other(format!("{:?}", value))
+        PyPolarsErr::Other(format!("{value:?}"))
     }
 }
 
@@ -37,13 +37,13 @@ impl std::convert::From<PyPolarsErr> for PyErr {
                 PolarsError::ShapeMisMatch(err) => ShapeError::new_err(err.to_string()),
                 PolarsError::SchemaMisMatch(err) => SchemaError::new_err(err.to_string()),
                 PolarsError::Io(err) => PyIOError::new_err(err.to_string()),
-                PolarsError::ArrowError(err) => ArrowErrorException::new_err(format!("{:?}", err)),
+                PolarsError::ArrowError(err) => ArrowErrorException::new_err(format!("{err:?}")),
                 PolarsError::Duplicate(err) => DuplicateError::new_err(err.to_string()),
                 PolarsError::InvalidOperation(err) => {
                     InvalidOperationError::new_err(err.to_string())
                 }
             },
-            Arrow(err) => ArrowErrorException::new_err(format!("{:?}", err)),
+            Arrow(err) => ArrowErrorException::new_err(format!("{err:?}")),
             _ => default(),
         }
     }
@@ -53,9 +53,9 @@ impl Debug for PyPolarsErr {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         use PyPolarsErr::*;
         match self {
-            Polars(err) => write!(f, "{:?}", err),
-            Other(err) => write!(f, "BindingsError: {:?}", err),
-            Arrow(err) => write!(f, "{:?}", err),
+            Polars(err) => write!(f, "{err:?}"),
+            Other(err) => write!(f, "BindingsError: {err:?}"),
+            Arrow(err) => write!(f, "{err:?}"),
         }
     }
 }
