@@ -4,6 +4,16 @@
 extern crate core;
 extern crate polars;
 
+#[cfg(feature = "build_info")]
+#[macro_use]
+extern crate pyo3_built;
+
+#[cfg(feature = "build_info")]
+#[allow(dead_code)]
+mod build {
+    include!(concat!(env!("OUT_DIR"), "/built.rs"));
+}
+
 pub mod apply;
 pub mod arrow_interop;
 #[cfg(feature = "csv-file")]
@@ -25,10 +35,10 @@ mod set;
 mod sql;
 pub mod utils;
 
-#[cfg(target_os = "linux")]
+#[cfg(all(target_os = "linux", not(use_mimalloc)))]
 use jemallocator::Jemalloc;
 use lazy::ToExprs;
-#[cfg(not(target_os = "linux"))]
+#[cfg(any(not(target_os = "linux"), use_mimalloc))]
 use mimalloc::MiMalloc;
 use polars::functions::{diag_concat_df, hor_concat_df};
 use polars::prelude::Null;
@@ -57,11 +67,11 @@ use crate::prelude::{
 use crate::series::PySeries;
 
 #[global_allocator]
-#[cfg(target_os = "linux")]
+#[cfg(all(target_os = "linux", not(use_mimalloc)))]
 static ALLOC: Jemalloc = Jemalloc;
 
 #[global_allocator]
-#[cfg(not(target_os = "linux"))]
+#[cfg(any(not(target_os = "linux"), use_mimalloc))]
 static ALLOC: MiMalloc = MiMalloc;
 
 #[pyfunction]
@@ -179,7 +189,14 @@ fn spearman_rank_corr(
     ddof: u8,
     propagate_nans: bool,
 ) -> dsl::PyExpr {
-    polars::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof, propagate_nans).into()
+    #[cfg(feature = "propagate_nans")]
+    {
+        polars::lazy::dsl::spearman_rank_corr(a.inner, b.inner, ddof, propagate_nans).into()
+    }
+    #[cfg(not(feature = "propagate_nans"))]
+    {
+        panic!("activate 'popagate_nans'")
+    }
 }
 
 #[pyfunction]
@@ -356,6 +373,23 @@ fn py_diag_concat_df(dfs: &PyAny) -> PyResult<PyDataFrame> {
     Ok(df.into())
 }
 
+#[pyfunction]
+fn py_diag_concat_lf(lfs: &PyAny, rechunk: bool, parallel: bool) -> PyResult<PyLazyFrame> {
+    let (seq, _len) = get_pyseq(lfs)?;
+    let iter = seq.iter()?;
+
+    let lfs = iter
+        .map(|item| {
+            let item = item?;
+            get_lf(item)
+        })
+        .collect::<PyResult<Vec<_>>>()?;
+
+    let lf = polars::lazy::dsl::functions::diag_concat_lf(lfs, rechunk, parallel)
+        .map_err(PyPolarsErr::from)?;
+    Ok(lf.into())
+}
+
 #[pyfunction]
 fn py_hor_concat_df(dfs: &PyAny) -> PyResult<PyDataFrame> {
     let (seq, _len) = get_pyseq(dfs)?;
@@ -481,7 +515,7 @@ fn py_date_range(
         Duration::parse(every),
         closed.0,
         tu.0,
-        tz,
+        tz.as_ref(),
     )
     .into_series()
     .into()
@@ -568,6 +602,13 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
         py.get_type::<InvalidOperationError>(),
     )
     .unwrap();
+
+    #[cfg(feature = "build_info")]
+    m.add(
+        "_build_info_",
+        pyo3_built!(py, build, "build", "time", "deps", "features", "host", "target", "git"),
+    )?;
+
     m.add_class::<PySeries>().unwrap();
     m.add_class::<PyDataFrame>().unwrap();
     m.add_class::<PyLazyFrame>().unwrap();
@@ -612,6 +653,7 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_wrapped(wrap_pyfunction!(spearman_rank_corr)).unwrap();
     m.add_wrapped(wrap_pyfunction!(map_mul)).unwrap();
     m.add_wrapped(wrap_pyfunction!(py_diag_concat_df)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(py_diag_concat_lf)).unwrap();
     m.add_wrapped(wrap_pyfunction!(py_hor_concat_df)).unwrap();
     m.add_wrapped(wrap_pyfunction!(py_datetime)).unwrap();
     m.add_wrapped(wrap_pyfunction!(py_duration)).unwrap();
