@@ -31,17 +31,20 @@ def test_diag_concat() -> None:
     b = pl.DataFrame({"b": ["a", "b"], "c": [1, 2]})
     c = pl.DataFrame({"a": [5, 7], "c": [1, 2], "d": [1, 2]})
 
-    out = pl.concat([a, b, c], how="diagonal")
-    expected = pl.DataFrame(
-        {
-            "a": [1, 2, None, None, 5, 7],
-            "b": [None, None, "a", "b", None, None],
-            "c": [None, None, 1, 2, 1, 2],
-            "d": [None, None, None, None, 1, 2],
-        }
-    )
+    for out in [
+        pl.concat([a, b, c], how="diagonal"),
+        pl.concat([a.lazy(), b.lazy(), c.lazy()], how="diagonal").collect(),
+    ]:
+        expected = pl.DataFrame(
+            {
+                "a": [1, 2, None, None, 5, 7],
+                "b": [None, None, "a", "b", None, None],
+                "c": [None, None, 1, 2, 1, 2],
+                "d": [None, None, None, None, 1, 2],
+            }
+        )
 
-    assert out.frame_equal(expected, null_equal=True)
+        assert out.frame_equal(expected, null_equal=True)
 
 
 def test_concat_horizontal() -> None:
@@ -248,6 +251,9 @@ def test_coalesce() -> None:
     assert df.select(pl.coalesce(["a", "b", "c", 10])).to_dict(False) == {
         "a": [1.0, 2.0, 3.0, 10.0]
     }
+    assert df.select(pl.coalesce(pl.col(["a", "b", "c"]))).to_dict(False) == {
+        "a": [1.0, 2.0, 3.0, None]
+    }
 
 
 def test_ones_zeros() -> None:
